class S3ExportConfiguration:

	def __init__(self, bucket_name, aws_access_key_id, aws_secret_access_key, aws_session_token):
		self.bucket_name = bucket_name
		self.aws_access_key_id = aws_access_key_id
		self.aws_secret_access_key = aws_secret_access_key
		self.aws_session_token = aws_session_token

	class Builder:

		def bucket_name(self, bucket_name):
			self.bucket_name = bucket_name
			return self

		def aws_access_key_id(self, aws_access_key_id):
			self.aws_access_key_id = aws_access_key_id
			return self

		def aws_secret_access_key(self, aws_secret_access_key):
			self.aws_secret_access_key = aws_secret_access_key
			return self

		def aws_session_token(self, aws_session_token):
			self.aws_session_token = aws_session_token
			return self

		def build(self):
			return S3ExportConfiguration(self.bucket_name, self.aws_access_key_id, self.aws_secret_access_key, self.aws_session_token)

# need to serialize/de- 

	def to_dict(self):
		return self.__dict__

	@staticmethod
	def from_dict(d):
		return S3ExportConfiguration(**d)






from ..tenant_config.get_tenant_config import *
from .config_exporter_registry import *
from ..common.call_export_record import call_export_record

def export_all(tenant, record):
	configs = get_tenant_configs(tenant)
	for key, config in configs:
		call_export_record(key, config, record)


		






from ..common.config_schemas.s3_config import S3ExportConfiguration
from .s3_export_record import S3ExportRecord

location_key_map = {
	"s3": (S3ExportConfiguration.from_dict, S3ExportRecord),
	"datadog": "coming soon",
	"other integrations": "...",
}

def get_export_objs(location_key):
	return location_key_map[location_key]



import requests
import os
# call the export record function over http from another function

def call_export_record(location_key, config, record):
	export_record_url = os.getenv("export_record_url")
	data = {
		"location_key": location_key,
		"config": config,
		"record": record,
	}

	requests.post(export_record_url, data=data)



	